#
# spec file for package barman
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         nsusr   barman
%define         nsgrp   barman

%if 0%{?suse_version} > 1230
%bcond_without systemd
%else
%bcond_with    systemd
%endif

Name:           barman
Version:        2.6
Release:        1.5
Summary:        Backup and Recovery Manager for PostgreSQL
License:        GPL-3.0-or-later
Group:          Productivity/Databases/Tools
URL:            http://www.pgbarman.org/
Source0:        http://downloads.sourceforge.net/project/pgbarman/%{version}/%{name}-%{version}.tar.gz
Source1:        http://downloads.sourceforge.net/project/pgbarman/%{version}/manual.pdf

Source2:        barman.logrotate
Source3:        barman.cron
Source4:        barman.service
Source5:        barman.timer

BuildRequires:  fdupes
BuildRequires:  python3-devel
Requires(pre):  %{_sbindir}/groupadd
Requires(pre):  %{_sbindir}/useradd
%if %{with systemd}
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%else #with_systemd
Requires:       cron
%endif #with_systemd
Requires:       logrotate
Requires:       python3-argcomplete
Requires:       python3-argh >= 0.21.2
Requires:       python3-dateutil
Requires:       python3-psycopg2
Requires:       rsync >= 3.0.4
BuildArch:      noarch

%description
Barman (backup and recovery manager) is an administration
tool for disaster recovery of PostgreSQL servers written in Python.
It allows to perform remote backups of multiple servers
in business critical environments and help DBAs during the recovery phase.
Barman offers most wanted features include backup catalogs, retention policies,
remote recovery, archiving and compression of WAL files and backups.
Barman is written and maintained by PostgreSQL professionals 2ndQuadrant.

%prep
%setup -q
cp %{SOURCE1} .

%build
python3 setup.py build

%install
python3 setup.py install -O1 --skip-build --root %{buildroot} --prefix=%{_prefix}

mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d
mkdir -p %{buildroot}%{_sysconfdir}/cron.d/
# Without dir barman from cron will spew every minute annoying message
# 2017-08-05 15:16:01,975 [27539] barman.config WARNING: Ignoring the "configuration_files_directory" option as "/etc/barman.d" is not a directory
mkdir -p %{buildroot}%{_sysconfdir}/barman.d/
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d/
mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}
mkdir -p %{buildroot}%{_localstatedir}/log/%{name}
install -pm 644 doc/barman.conf %{buildroot}%{_sysconfdir}/%{name}.conf
install -pm 644 scripts/barman.bash_completion %{buildroot}%{_sysconfdir}/bash_completion.d/%{name}
%if %{with systemd}
install -D -m 644 %{SOURCE4} %{buildroot}%{_unitdir}/%{name}.service
install -D -m 644 %{SOURCE5} %{buildroot}%{_unitdir}/%{name}.timer
%else
install -pm 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/cron.d/%{name}
%endif
install -pm 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
touch %{buildroot}%{_localstatedir}/log/%{name}/%{name}.log

%fdupes %{buildroot}%{python3_sitelib}

%pre
groupadd -f -r %{name} >/dev/null 2>&1 || :
useradd -g %{name} -r -d %{_localstatedir}/lib/%{name} -s /bin/bash \
    -c "Backup and Recovery Manager for PostgreSQL" %{name} >/dev/null 2>&1 || :
%if %{with systemd}
%service_add_pre %{name}.service %{name}.timer

%post
%service_add_post %{name}.service %{name}.timer

%preun
%service_del_preun %{name}.service %{name}.timer

%postun
%service_del_postun %{name}.service %{name}.timer
%endif

%files
%defattr(-,root,root,-)
%license LICENSE
%doc README.rst ChangeLog NEWS manual.pdf
%{_bindir}/%{name}
%{python3_sitelib}/%{name}-%{version}-*.egg-info
%{python3_sitelib}/%{name}/
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man5/%{name}.5%{?ext_man}
#
%config(noreplace) %attr(640,root,%{nsgrp}) %{_sysconfdir}/barman.conf
%config(noreplace) %attr(750,root,%{nsgrp}) %{_sysconfdir}/barman.d/
%config(noreplace) %{_sysconfdir}/bash_completion.d/barman
%config(noreplace) %{_sysconfdir}/logrotate.d/barman
%if %{with systemd}
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}.timer
%else
%config(noreplace) %{_sysconfdir}/cron.d/%{name}
%endif
#
%attr(700,%{nsusr},%{nsgrp}) %dir %{_localstatedir}/lib/%{name}
%attr(700,%{nsusr},%{nsgrp}) %dir %{_localstatedir}/log/%{name}
%attr(600,%{nsusr},%{nsgrp}) %ghost %{_localstatedir}/log/%{name}/%{name}.log

%changelog
* Fri Feb  8 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 2.6
  - Add support for Geographical redundancy, introducing 3 new
    commands: sync-info, sync-backup and sync-wals.  Geo-redundancy
    allows a Barman server to use another Barman server as data
    source instead of a PostgreSQL server.
  - Add put-wal command that allows Barman to safely receive WAL
    files via PostgreSQL’s archive_command using the
    barman-wal-archive script included in barman-cli
  - Add ANSI colour support to check command
  - Minor fixes:
  - Fix switch-wal on standby with an empty WAL directory
  - Honour archiver locking in wait_for_wal method
  - Fix WAL compression detection algorithm
  - Fix current_action in concurrent stop backup errors
  - Do not treat lock file busy as an error when validating a
    backup
* Sat Oct 27 2018 Marcus Rueckert <mrueckert@suse.de>
- update to 2.5
  - Add support for PostgreSQL 11
  - Add check-backup command to verify that WAL files required for
    consistency of a base backup are present in the archive. Barman
    now adds a new state (WAITING_FOR_WALS) after completing a base
    backup, and sets it to DONE once it has verified that all WAL
    files from start to the end of the backup exist. This command
    is included in the regular cron maintenance job.  Barman now
    notifies users attempting to recover a backup that is in
    WAITING_FOR_WALS state.
  - Allow switch-xlog --archive to work on a standby (just for the
    archive part)
  - Bug fixes:
  - Fix decoding errors reading external commands output (issue
    [#174])
  - Fix documentation regarding WAL streaming and backup from
    standby
* Tue Jun 26 2018 mrueckert@suse.de
- Migrated to systemd timers for all systemd based distros.
  You need to run:
  systemctl enable barman.timer
  systemctl start  barman.timer
  To reenable the the automatic running again.
- move cron and logrotate file to source instead of heredoc
* Tue Jun 26 2018 mrueckert@suse.de
- move package to use python3
  - properly use all python3 macros through out the spec file
- clean up spec file with spec-cleaner
- tighten permissions of config:
  old: root:root   u=rwX,go=rX
  new: root:barman u=rwX,g=rX,o=
- tighten permissions of the log dir
  old: barman:barman u=rwX,go=rX
  new: barman:barman u=rwX,go=
* Fri Jun  1 2018 mrueckert@suse.de
- update to 2.4
  - Main changes
  - Add standard and retry hook scripts for backup deletion
    (pre/post)
  - Add standard and retry hook scripts for recovery (pre/post)
  - Add standard and retry hook scripts for WAL deletion
    (pre/post)
  - Add --standby-mode option to barman recover to add
    standby_mode = on in pre-generated recovery.conf
  - Add --target-action option to barman recover, allowing users
    to add shutdown, pause or promote to the pre-generated
    recovery.conf file
  - Improve usability of point-in-time recovery with consistency
    checks (e.g. recovery time is after end time of backup)
  - Minor documentation improvements
  - Drop support for Python 3.3
  - Relevant bug fixes:
  - Fix remote get_file_content method (Github #151), preventing
    incremental recovery from happening
  - Unicode issues with command (Github #143 and #150)
  - Add --wal-method=none when pg_basebackup >= 10 (Github #133)
  - Minor bug fixes:
  - Stop process manager module from ovewriting lock files
    content
  - Relax the rules for rsync output parsing
  - Ignore vanished files in streaming directory
  - Case insensitive slot names (Github #170)
  - Make DataTransferFailure.from_command_error() more resilient
    (Github #86)
  - Rename command() to barman_command() (Github #118)
  - Initialise synchronous standby names list if not set (Github
    [#111])
  - Correct placeholders ordering (GitHub #138)
  - Force datestyle to iso for replication connections
  - Returns error if delete command does not remove the backup
  - Fix exception when calling is_power_of_two(None)
  - Downgraded sync standby names messages to debug (Github #89)
* Fri Sep  8 2017 mrueckert@suse.de
- update to 2.3
  - Add support to PostgreSQL 10
  - Follow naming changes in PostgreSQL 10:
  - The switch-xlog command has been renamed to switch-wal.
  - In commands output, the xlog word has been changed to WAL and
    location has been changed to LSN when appropriate.
  - Add the --network-compression/--no-network-compression options
    to barman recover to enable or disable network compression at
    run-time
  - Add --target-immediate option to recover command, in order to
    exit recovery when a consistent state is reached (end of the
    backup, available from PostgreSQL 9.4)
  - Show cluster state (master or standby) with barman status
    command
  - Documentation improvements
  - Bug fixes:
  - Fix high memory usage with parallel_jobs > 1 (#116)
  - Better handling of errors using parallel copy (#114)
  - Make barman diagnose more robust with system exceptions
  - Let archive-wal ignore files with .tmp extension
- update manual to 2.3
* Sat Aug  5 2017 boris@steki.net
- create /etc/barman.d as required by default configuration
  or crontab will fill up logs with info about missing directory
* Thu Aug  3 2017 mrueckert@suse.de
- update to 2.2:
  - Implement parallel copy for backup/recovery through the
    parallel_jobs global/server option to be overridden by the
  - -jobs or -j runtime option for the backup and recover command.
    Parallel backup is available only for the rsync copy method. By
    default, it is set to 1 (for behaviour compatibility with
    previous versions).
  - Support custom WAL size for PostgreSQL 8.4 and newer. At backup
    time, Barman retrieves from PostgreSQL wal_segment_size and
    wal_block_size values and computes the necessary calculations.
  - Improve check command to ensure that incoming directory is
    empty when archiver=off, and streaming directory is empty when
    streaming_archiver=off (#80).
  - Add external_configuration to backup_options so that users can
    instruct Barman to ignore backup of configuration files when
    they are not inside PGDATA (default for Debian/Ubuntu
    installations). In this case, Barman does not display a warning
    anymore.
  - Add --get-wal and --no-get-wal options to barman recover
  - Add max_incoming_wals_queue global/server option for the check
    command so that a non blocking error is returned in case
    incoming WAL directories for both archiver and the
    streaming_archiver contain more files than the specified value.
  - Documentation improvements
  - File format changes:
  - The format of backup.info file has changed. For this reason a
    backup taken with Barman 2.2 cannot be read by a previous
    version of Barman. But, backups taken by previous versions
    can be read by Barman 2.2.
  - Minor bug fixes:
  - Allow replication-status to work against a standby
  - Close any PostgreSQL connection before starting pg_basebackup
    (#104, #108)
  - Safely handle paths containing special characters
  - Archive .partial files after promotion of streaming source
  - Recursively create directories during recovery (SF#44)
  - Improve xlog.db locking (#99)
  - Remove tablespace_map file during recover (#95)
  - Reconnect to PostgreSQL if connection drops (SF#82)
* Tue Feb  7 2017 bo@suse.de
- update to 2.1:
  - Add --archive and --archive-timeout options to switch-xlog command
  - Preliminary support for PostgreSQL 10 (#73)
  - Minor additions:
  - Add last archived WAL info to diagnose output
  - Add start time and execution time to the output of delete command
  - Minor bug fixes:
  - Return failure for get-wal command on inactive server
  - Make streaming_archiver_names and streaming_backup_name options
    global (#57)
  - Fix rsync failures due to files truncated during transfer (#64)
  - Correctly handle compressed history files (#66)
  - Avoid de-referencing symlinks in pg_tblspc when preparing
    recovery (#55)
  - Fix comparison of last archiving failure (#40, #58)
  - Avoid failing recovery if postgresql.conf is not writable (#68)
  - Fix output of replication-status command (#56)
  - Exclude files from backups like pg_basebackup (#65, #72)
  - Exclude directories from other Postgres versions while copying
    tablespaces (#74)
  - Make retry hook script options global
- updated manual to 2.1 version
* Mon Oct  3 2016 mrueckert@suse.de
- update to 2.0:
  - Support for pg_basebackup and base backups over the PostgreSQL
    streaming replication protocol with backup_method=postgres
    (PostgreSQL 9.1 or higher required)
  - Support for physical replication slots through the slot_name
    configuration option as well as the --create-slot and
  - -drop-slot options for the receive-wal command (PostgreSQL 9.4
    or higher required). When slot_name is specified and
    streaming_archiver is enabled, receive-wal transparently
    integrates with pg_receivexlog, and check makes sure that slots
    exist and are actively used
  - Support for the new backup API introduced in PostgreSQL 9.6,
    which transparently enables concurrent backups and backups from
    standby servers using the standard rsync method of backup.
    Concurrent backup was only possible for PostgreSQL 9.2 to 9.5
    versions through the pgespresso extension. The new backup API
    will make pgespresso redundant in the future
  - If properly configured, Barman can function as a synchronous
    standby in terms of WAL streaming. By properly setting the
    streaming_archiver_name in the synchronous_standby_names
    priority list on the master, and enabling replication slot
    support, the receive-wal command can now be part of a
    PostgreSQL synchronous replication cluster, bringing RPO=0
    (PostgreSQL 9.5.5 or higher required)
  - Introduce barman-wal-restore, a standard and robust script
    written in Python that can be used as restore_command in
    recovery.conf files of any standby server of a cluster. It
    supports remote parallel fetching of WAL files by efficiently
    invoking get-wal through SSH.  Currently available as a
    separate project called barman-cli. The barman-cli package is
    required for remote recovery when get-wal is listed in
    recovery_options
  - Control the maximum execution time of the check command through
    the check_timeout global/server configuration option (30
    seconds by default)
  - Limit the number of WAL segments that are processed by an
    archive-wal run, through the archiver_batch_size and
    streaming_archiver_batch_size global/server options which
    control archiving of WAL segments coming from, respectively,
    the standard archiver and receive-wal
  - Removed locking of the XLOG database during check operations
  - The show-backup command is now aware of timelines and properly
    displays which timelines can be used as recovery targets for a
    given base backup. Internally, Barman is now capable of parsing
    .history files
  - Improved the logic behind the retry mechanism when copy
    operations experience problems. This involves backup (rsync and
    postgres) as well as remote recovery (rsync)
  - Code refactoring involving remote command and physical copy
    interfaces
  - Bug fixes:
  - Correctly handle .history files from streaming
  - Fix replication-status on PostgreSQL 9.1
  - Fix replication-status when sent and write locations are not
    available
  - Fix misleading message on pg_receivexlog termination
- replace tutorial.pdf with manual.pdf
* Wed May  4 2016 mrueckert@suse.de
- update to 1.6.0
  - Support for streaming replication connection through the
    streaming_conninfo server option
  - Support for the streaming_archiver option that allows Barman to
    receive WAL files through PostgreSQL's native streaming
    protocol.  When set to 'on', it relies on pg_receivexlog to
    receive WAL data, reducing Recovery Point Objective. Currently,
    WAL streaming is an additional feature (standard log archiving
    is still required)
  - Implement the receive-wal command that, when streaming_archiver
    is on, wraps pg_receivexlog for WAL streaming. Add --stop
    option to stop receiving WAL files via streaming protocol. Add
  - -reset option to reset the streaming status and restart from
    the current xlog in Postgres.
  - Automatic management (startup and stop) of receive-wal command
    via cron command
  - Support for the path_prefix configuration option
  - Introduction of the archiver option (currently fixed to on)
    which enables continuous WAL archiving for a specific server,
    through log shipping via PostgreSQL's archive_command
  - Support for streaming_wals_directory and errors_directory
    options
  - Management of WAL duplicates in archive-wal command and
    integration with check command
  - Verify if pg_receivexlog is running in check command when
    streaming_archiver is enabled
  - Verify if failed backups are present in check command
  - Accept compressed WAL files in incoming directory
  - Add support for the pigz compressor (thanks to Stefano
    Zacchiroli zack@upsilon.cc)
  - Implement pygzip and pybzip2 compressors (based on an initial
    idea of Christoph Moench-Tegeder christoph@2ndquadrant.de)
  - Creation of an implicit restore point at the end of a backup
  - Current size of the PostgreSQL data files in barman status
  - Permit archive_mode=always for PostgreSQL 9.5 servers (thanks
    to Christoph Moench-Tegeder christoph@2ndquadrant.de)
  - Complete refactoring of the code responsible for connecting to
    PostgreSQL
  - Improve messaging of cron command regarding sub-processes
  - Native support for Python >= 3.3
  - Changes of behaviour:
  - Stop trashing WAL files during archive-wal (commit:e3a1d16)
  - Bug fixes:
  - Atomic WAL file archiving (#9 and #12)
  - Propagate "-c" option to any Barman subprocess (#19)
  - Fix management of backup ID during backup deletion (#22)
  - Improve archive-wal robustness and log messages (#24)
  - Improve error handling in case of missing parameters
* Wed Jun 10 2015 mrueckert@suse.de
- relax the dateutils requires again
* Wed Jun 10 2015 mrueckert@suse.de
- update to 1.4.1
  - Fix for WAL archival stop working if first backup is EMPTY
    (Closes: #64)
  - Fix exception during error handling in Barman recovery (Closes:
    [#] 65)
  - After a backup, limit cron activity to WAL archiving only
    (Closes: #62)
  - Improved robustness and error reporting of the backup delete
    command (Closes: #63)
  - Fix computation of WAL production ratio as reported in the
    show-backup command
  - Improved management of xlogb file, which is now correctly
    fsynced when updated. Also, the rebuild-xlogdb command now
    operates on a temporary new file, which overwrites the main one
    when finished.
  - Add unit tests for dateutil module compatibility
  - Modified Barman version following PEP 440 rules and added
    support of tests in Python 3.4
- changes from 1.4.0
  - Incremental base backup implementation through the reuse_backup
    global/server option. Possible values are off (disabled,
    default), copy (preventing unmodified files from being
    transferred) and link (allowing for deduplication through hard
    links).
  - Store and show deduplication effects when using reuse_backup=
    link.
  - Added transparent support of pg_stat_archiver (PostgreSQL 9.4)
    in check, show-server and status commands.
  - Improved administration by invoking WAL maintenance at the end
    of a successful backup.
  - Changed the way unused WAL files are trashed, by
    differentiating between concurrent and exclusive backup cases.
  - Improved performance of WAL statistics calculation.
  - Treat a missing pg_ident.conf as a WARNING rather than an
    error.
  - Refactored output layer by removing remaining yield calls.
  - Check that rsync is in the system path.
  - Include history files in WAL management.
  - Improved robustness through more unit tests.
  - Fixed bug #55: Ignore fsync EINVAL errors on directories.
  - Fixed bug #58: retention policies delete.
- unified tabs and spaces to spaces in the spec file
- added barman-tutorial.en.pdf to the documentation
- dont use sles_version for the noarch conditional. suse_version >
  1110 is better.
- python-argcomplete requires didnt use the __python_ver macro
  got noticed when i tried to build it with python 3
- documentation says we need dateutils < 2 as >= 2.0 requires
  python3. Encode that also in the requires
- add requires for rsync as specified in the docs
* Mon Sep  8 2014 boris@steki.net
- updated to latest upstream version 1.3.3
  + most notable changes are:
  - refactored building of full path of a WAL file
  - Estimates WAL production rate for a backup
  - Really fix "ssh" version detection in "barman diagnose" command
  - Add command line options for retry of backup/recover copy
  - Implemented the --retry-times (including --no-retry) and --retry-sleep
  - Display compression ratio for WALs in show-backup
  - Support for 'last_backup_max_age'
    This new global/server option allows administrators
    to set the max age of the last backup, making it easier
    to detect any issues with periodical backup execution.
  - Support for "smart" incremental recovery
    Avoid invoking rsync with --checksum option during recovery
  - Use Postgres' server time for both begin_time and end_time
  - Retry option for base backup
    If a network error happens during rsync, add the ability
    to retry a defined number of time.
- for verbose changelog please read changes info in
  /usr/share/doc/packages/barman/ChangeLog
* Tue Feb  4 2014 boris@steki.net
- updated to latest upstream version 1.3.0
  * Refactored BackupInfo class for backup
    metadata to use the new FieldListFile class (infofile module)
  * Refactored output layer to use a dedicated module, in order to
    facilitate integration with Nagios (NagiosOutputWriter class)
  * Refactored subprocess handling in order to isolate stdin/stderr/
    stdout channels (command_wrappers module)
  * Refactored hook scripts management
  * Extracted logging configuration and userid
    enforcement from the configuration class.
  * Support for hook scripts to be executed before and after
    a WAL file is archived, through the 'pre_archive_script'
    and 'post_archive_script' configuration options.
  * Implemented immediate checkpoint capability with
  - -immediate-checkpoint command option and 'immediate_checkpoint'
    configuration option
  * Implemented network compression for remote backup and recovery
    through the 'network_compression' configuration option (#19)
  * Implemented the 'rebuild-xlogdb' command (Closes #27 and #28)
  * Added deduplication of tablespaces located inside the PGDATA directory
  * Refactored remote recovery code to work the same way local recovery
    does, by performing remote directory preparation (assuming
    the remote user has the right permissions on the remote server)
  * 'barman backup' now tries and create server directories before
    attempting to execute a full backup (#14)
  * Fixed bug #22: improved documentation for tablespaces relocation
  * Fixed bug #31: 'barman cron' checks directory permissions for lock file
  * Fixed bug #32: xlog.db read access during cron activities
* Fri Oct  4 2013 boris@steki.net
- updated to latest upstream 1.2.3
  - Added support for PostgreSQL 9.3
  - Added support for the "--target-name" recovery option,
    which allows to restore to a named point previously
    specified with pg_create_restore_point
    (only for PostgreSQL 9.1 and above users)
  - Fix python 2.6 compatibility
  - Added the "bandwidth_limit" global/server option which allows
    to limit the I/O bandwidth (in KBPS)
    for backup and recovery operations
* Thu Mar  7 2013 darin@darins.net
- comment require python-abi
- require python-argh >=0.21.2
* Wed Mar  6 2013 darin@darins.net
- Update to 1.2.0
- fix group
* Tue Jan 15 2013 darin@darins.net
- Update and cleanup .spec for OpenSUSE
- Moved %%changlog to .changes
* Thu Nov 29 2012 marco.nenciarini@2ndquadrant.it
- New release 1.1.2
* Tue Oct 16 2012 marco.nenciarini@2ndquadrant.it
- New release 1.1.1
* Fri Oct 12 2012 marco.nenciarini@2ndquadrant.it
- New release 1.1.0
- Some improvements from Devrim Gunduz <devrim@gunduz.org>
* Fri Jul  6 2012 marco.nenciarini@2ndquadrant.it
- Open source release
* Thu May 17 2012 marco.nenciarini@2ndquadrant.it
- Fixed documentation
* Tue May 15 2012 marco.nenciarini@2ndquadrant.it
- Add cron job
* Wed May  9 2012 marco.nenciarini@2ndquadrant.it
- Update to version 0.99.0
* Tue Dec  6 2011 marco.nenciarini@2ndquadrant.it
- Initial packaging.
